import java.io.*;
import java.math.*;
import java.util.*;

public class TestsGen {

    int testCount;

    void write(String s) throws IOException {
        PrintWriter pw = new PrintWriter(String.format("../tests/%02d", ++testCount));
        System.out.println(testCount);
        pw.println(s);
        pw.close();
    }

    void write(int n, int a[]) throws IOException {
        PrintWriter pw = new PrintWriter(String.format("../tests/%02d", ++testCount));
        System.out.println(testCount);
		pw.println(n);
        for (int i = 0; i < a.length - 1; i++) pw.print(a[i] + " ");
		pw.println(a[a.length - 1]);
        pw.close();
    }
    
    Random random = new Random(43534543);

	void genSample() throws IOException {
		write("1\r\n1 2");
		write("1\r\n2 1");
	}

	void shuffle(int[] a) {
	 	for (int i = 1; i < a.length; i++) {
			int k = random.nextInt(i + 1);
			int o = a[i];
			a[i] = a[k];
			a[k] = o;
		}
	}

	void reverse(int[] a) {
	 	for (int l = 0, r = a.length - 1; l < r; l++, r--) {
	 	 	int o = a[l];
			a[l] = a[r];
			a[r] = o;
		}
	}

	void genRandom(int n) throws IOException {
	 	int a[] = new int[1 << n];
		for (int i = 0; i < 1 << n; i++) {
			a[i] = i + 1;
		}
		shuffle(a);
		write(n, a);
	}

	void genId(int n) throws IOException {
	 	int a[] = new int[1 << n];
		for (int i = 0; i < 1 << n; i++) {
			a[i] = i + 1;
		}
		write(n, a);
	}

	void genIdInv(int n) throws IOException {
	 	int a[] = new int[1 << n];
		for (int i = 0; i < 1 << n; i++) {
			a[i] = i + 1;
		}
		reverse(a);
		write(n, a);
	}

	int inv(int x, int n) {
		int res = 0;
		for (int i = 0; i < n; i++) {
		 	if ((x & (1 << i)) != 0) {
		 	 	res |= 1 << (n - i - 1);
			}
		}
		return res;
	}

	void genFFT(int n) throws IOException {
	 	int a[] = new int[1 << n];
		for (int i = 0; i < 1 << n; i++) {
			a[i] = i + 1;
		}
		for (int i = 0; i < 1 << n; i++) {
	     	int j = inv(i, n);
			if (i <= j) {
			 	int x = a[i];
				a[i] = a[j];	
				a[j] = x;
			}
		}
		write(n, a);
	}

    void run() throws IOException {
        new File("../tests").mkdir();
        
		genSample();
		for (int n = 2; n <= 15; n++) {
		 	genRandom(n);
		}
		for (int n = 5; n <= 15; n += 5) {
		 	genId(n);
		}
		for (int n = 5; n <= 15; n += 5) {
		 	genIdInv(n);
		}
		for (int n = 6; n <= 15; n += 3) {
		 	genFFT(n);
		}
		
    }

    public static void main(String[] args) throws IOException {
        new TestsGen().run();    }

}
